from setuptools import setup

setup(name='Gaussian_binomial_dists',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['Gaussian_binomial_dists'],
      zip_safe=False)
